==> haskell-base-prelude-1.2.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.2.0.1
id: base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
key: base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BasePrelude
abi: 3e78347d5a15e89f4fb1084b18368182
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/base-prelude-1.2.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/base-prelude-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/base-prelude-1.2.0.1
hs-libraries: HSbase-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.2.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.2.1
id: base-prelude-1.2.1-9DojpA5E5OtH7FZzMevW8v
key: base-prelude-1.2.1-9DojpA5E5OtH7FZzMevW8v
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BasePrelude
abi: 4a6c49e31ccaae1a3e4ac7975d1ab849
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/base-prelude-1.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/base-prelude-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/base-prelude-1.2.1
hs-libraries: HSbase-prelude-1.2.1-9DojpA5E5OtH7FZzMevW8v
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
